.. _water:

H2O-BLYP-Piglet
###############

This dataset contains 27233 hydrogen bond descriptors and corresponding weights from a
trajectory of a classical simulation performed with a BLYP exchange-correlation
functional and a DZVP basis set. The simulation box contined 64 water molecules. This
dataset was originally published in
[Gasparotto2014]_.

Function Call
-------------

.. function:: skmatter.datasets.load_hbond_dataset

Data Set Characteristics
------------------------

:Number of Instances: 27233

:Number of Features: 3

Reference
---------

[1] https://github.com/lab-cosmo/pamm/tree/master/examples/water

Reference Code
--------------

[2] https://github.com/GardevoirX/pypamm/blob/master/tutorials/water/tutorial.ipynb

[3] https://github.com/lab-cosmo/pamm/blob/master/examples/water/README

